==> apache-hugegraph-toolchain-incubating-1.2.0-src.tar.gz: apache-hugegraph-toolchain-incubating-1.2.0-src/hugegraph-hubble/hubble-be/src/main/java/org/apache/hugegraph/HugeGraphHubble.java <==
/*
 *
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with this
 * work for additional information regarding copyright ownership. The ASF
 * licenses this file to You under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations
 * under the License.
 */

package org.apache.hugegraph;

import org.apache.commons.lang3.StringUtils;
import org.apache.hugegraph.util.Ex;
import org.mybatis.spring.annotation.MapperScan;
import org.springframework.boot.SpringApplication;
import org.springframework.boot.autoconfigure.SpringBootApplication;
import org.springframework.boot.builder.SpringApplicationBuilder;
import org.springframework.boot.web.servlet.support.SpringBootServletInitializer;
import org.springframework.scheduling.annotation.EnableScheduling;

@SpringBootApplication
@EnableScheduling
@MapperScan("org.apache.hugegraph.mapper")
public class HugeGraphHubble extends SpringBootServletInitializer {

    public static void main(String[] args) {
        initEnv();
        SpringApplication.run(HugeGraphHubble.class, args);
    }

    public static void initEnv() {
        String hubbleHomePath = System.getProperty("hubble.home.path");
        Ex.check(StringUtils.isNotEmpty(hubbleHomePath),
                 "The system property 'hubble.home.path' must be set");
        String loaderHomePath = System.getProperty("loader.home.path");
        if (StringUtils.isEmpty(loaderHomePath)) {
            System.setProperty("loader.home.path", hubbleHomePath);
        }
    }

    @Override
    protected SpringApplicationBuilder configure(
                                       SpringApplicationBuilder builder) {
        return builder.sources(this.getClass());
    }
}

==> apache-hugegraph-toolchain-incubating-1.3.0-src.tar.gz: apache-hugegraph-toolchain-incubating-1.3.0-src/hugegraph-hubble/hubble-be/src/main/java/org/apache/hugegraph/HugeGraphHubble.java <==
/*
 *
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with this
 * work for additional information regarding copyright ownership. The ASF
 * licenses this file to You under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations
 * under the License.
 */

package org.apache.hugegraph;

import org.apache.commons.lang3.StringUtils;
import org.apache.hugegraph.util.Ex;
import org.mybatis.spring.annotation.MapperScan;
import org.springframework.boot.SpringApplication;
import org.springframework.boot.autoconfigure.SpringBootApplication;
import org.springframework.boot.builder.SpringApplicationBuilder;
import org.springframework.boot.web.servlet.support.SpringBootServletInitializer;
import org.springframework.scheduling.annotation.EnableScheduling;

@SpringBootApplication
@EnableScheduling
@MapperScan("org.apache.hugegraph.mapper")
public class HugeGraphHubble extends SpringBootServletInitializer {

    public static void main(String[] args) {
        initEnv();
        SpringApplication.run(HugeGraphHubble.class, args);
    }

    public static void initEnv() {
        String hubbleHomePath = System.getProperty("hubble.home.path");
        Ex.check(StringUtils.isNotEmpty(hubbleHomePath),
                 "The system property 'hubble.home.path' must be set");
        String loaderHomePath = System.getProperty("loader.home.path");
        if (StringUtils.isEmpty(loaderHomePath)) {
            System.setProperty("loader.home.path", hubbleHomePath);
        }
    }

    @Override
    protected SpringApplicationBuilder configure(SpringApplicationBuilder builder) {
        return builder.sources(this.getClass());
    }
}
